    //
//  RightViewController.m
//  MathMonsters
//
//  Created by Ray Wenderlich on 5/3/10.
//  Copyright 2010 Ray Wenderlich. All rights reserved.
//

#import "RightViewController.h"
#import "Monster.h"

@implementation RightViewController
@synthesize monster = _monster;
@synthesize nameLabel = _nameLabel;
@synthesize descrLabel = _descrLabel;
@synthesize iconView = _iconView;
@synthesize weaponView = _weaponView;
@synthesize popover = _popover;
@synthesize toolbar = _toolbar;
@synthesize colorPicker = _colorPicker;
@synthesize colorPickerPopover = _colorPickerPopover;

/*
 // The designated initializer.  Override if you create the controller programmatically and want to perform customization that is not appropriate for viewDidLoad.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Overriden to allow any orientation.
    return YES;
}


- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
    self.nameLabel = nil;
    self.descrLabel = nil;
    self.iconView = nil;
    self.weaponView = nil;
}


- (void)viewDidUnload {
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}


- (void)dealloc {
    self.monster = nil;
    self.nameLabel = nil;
    self.descrLabel = nil;
    self.iconView = nil;
    self.weaponView = nil;
    self.popover = nil;
    self.toolbar = nil;
    self.colorPicker = nil;
    self.colorPickerPopover = nil;
    [super dealloc];    
}

- (void)refresh {
    _nameLabel.text = _monster.name;
    _iconView.image = [UIImage imageNamed:_monster.iconName];
    _descrLabel.text = _monster.descr;
    if (_monster.preferredWayToKill == Blowgun) {
        _weaponView.image = [UIImage imageNamed:@"blowgun.png"];
    } else if (_monster.preferredWayToKill == Fire) {
        _weaponView.image = [UIImage imageNamed:@"fire.png"];
    } else if (_monster.preferredWayToKill == NinjaStar) {
        _weaponView.image = [UIImage imageNamed:@"ninjastar.png"];
    } else if (_monster.preferredWayToKill == Smoke) {
        _weaponView.image = [UIImage imageNamed:@"smoke.png"];
    } else {
        _weaponView.image = [UIImage imageNamed:@"sword.png"];
    }
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    [self refresh];
}

- (void)monsterSelectionChanged:(Monster *)curSelection {
    self.monster = curSelection;
    
    if (_popover != nil) {
        [_popover dismissPopoverAnimated:YES];
    }    
    
    [self refresh];
}

#pragma mark UISplitViewControllerDelegate

- (void)splitViewController: (UISplitViewController*)svc willHideViewController:(UIViewController *)aViewController withBarButtonItem:(UIBarButtonItem*)barButtonItem forPopoverController: (UIPopoverController*)pc {
    barButtonItem.title = @"Monsters";
    NSMutableArray *items = [[_toolbar items] mutableCopy];
    [items insertObject:barButtonItem atIndex:0];
    [_toolbar setItems:items animated:YES];
    [items release];
    self.popover = pc;
}

- (void)splitViewController: (UISplitViewController*)svc willShowViewController:(UIViewController *)aViewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem {    
    NSMutableArray *items = [[_toolbar items] mutableCopy];
    [items removeObjectAtIndex:0];
    [_toolbar setItems:items animated:YES];
    [items release];
    self.popover = nil;
}


#pragma mark ColorPickerDelegate

- (void)colorSelected:(NSString *)color {
    if ([color compare:@"Red"] == NSOrderedSame) {
        _nameLabel.textColor = [UIColor redColor];
    } else if ([color compare:@"Green"] == NSOrderedSame) {
        _nameLabel.textColor = [UIColor greenColor];
    } else if ([color compare:@"Blue"] == NSOrderedSame){
        _nameLabel.textColor = [UIColor blueColor];
    }
    [self.colorPickerPopover dismissPopoverAnimated:YES];
}

#pragma mark Callbacks

- (IBAction)setColorButtonTapped:(id)sender {
    if (_colorPicker == nil) {
        self.colorPicker = [[[ColorPickerController alloc] initWithStyle:UITableViewStylePlain] autorelease];
        _colorPicker.delegate = self;
        self.colorPickerPopover = [[[UIPopoverController alloc] initWithContentViewController:_colorPicker] autorelease];               
    }
    [self.colorPickerPopover presentPopoverFromBarButtonItem:sender permittedArrowDirections:UIPopoverArrowDirectionAny animated:YES];
}

@end
